==> spring-cloud-contract-verifier-2.2.5.RELEASE-sources.jar: org/springframework/cloud/contract/verifier/TestGenerator.java <==
package org.springframework.cloud.contract.verifier;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import static org.springframework.cloud.contract.verifier.util.NamesUtil.afterLast;
import static org.springframework.cloud.contract.verifier.util.NamesUtil.beforeLast;
import static org.springframework.cloud.contract.verifier.util.NamesUtil.convertIllegalPackageChars;
import static org.springframework.cloud.contract.verifier.util.NamesUtil.directoryToPackage;
import static org.springframework.cloud.contract.verifier.util.NamesUtil.toLastDot;

@groovy.transform.CompileStatic() public class TestGenerator
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public TestGenerator
(org.springframework.cloud.contract.verifier.config.ContractVerifierConfigProperties configProperties) {
super ();
}
public TestGenerator
(org.springframework.cloud.contract.verifier.config.ContractVerifierConfigProperties configProperties, org.springframework.cloud.contract.verifier.builder.SingleTestGenerator generator, org.springframework.cloud.contract.verifier.FileSaver saver) {}
public TestGenerator
(org.springframework.cloud.contract.verifier.config.ContractVerifierConfigProperties configProperties, org.springframework.cloud.contract.verifier.builder.SingleTestGenerator generator, org.springframework.cloud.contract.verifier.FileSaver saver, org.springframework.cloud.contract.verifier.file.ContractFileScanner contractFileScanner) {}
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  int generate() { return (int)0;}
@groovy.transform.PackageScope() public  void generateTestClasses(java.lang.String basePackageName) { }
@groovy.transform.PackageScope() @groovy.transform.CompileDynamic() public  java.util.Set<java.util.Map.Entry<java.nio.file.Path, java.util.List<org.springframework.cloud.contract.verifier.file.ContractMetadata>>> processAllNotInProgress(org.springframework.util.MultiValueMap<java.nio.file.Path, org.springframework.cloud.contract.verifier.file.ContractMetadata> contracts, java.lang.String basePackageName) { return (java.util.Set<java.util.Map.Entry<java.nio.file.Path, java.util.List<org.springframework.cloud.contract.verifier.file.ContractMetadata>>>)null;}
protected static  java.lang.String buildPackage(java.lang.String packageNameForClass, java.lang.String includedDirectoryRelativePath) { return (java.lang.String)null;}
}

==> spring-cloud-contract-verifier-2.2.6.RELEASE-sources.jar: org/springframework/cloud/contract/verifier/TestGenerator.java <==
package org.springframework.cloud.contract.verifier;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import static org.springframework.cloud.contract.verifier.util.NamesUtil.afterLast;
import static org.springframework.cloud.contract.verifier.util.NamesUtil.beforeLast;
import static org.springframework.cloud.contract.verifier.util.NamesUtil.convertIllegalPackageChars;
import static org.springframework.cloud.contract.verifier.util.NamesUtil.directoryToPackage;
import static org.springframework.cloud.contract.verifier.util.NamesUtil.toLastDot;

@groovy.transform.CompileStatic() public class TestGenerator
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public TestGenerator
(org.springframework.cloud.contract.verifier.config.ContractVerifierConfigProperties configProperties) {
super ();
}
public TestGenerator
(org.springframework.cloud.contract.verifier.config.ContractVerifierConfigProperties configProperties, org.springframework.cloud.contract.verifier.builder.SingleTestGenerator generator, org.springframework.cloud.contract.verifier.FileSaver saver) {}
public TestGenerator
(org.springframework.cloud.contract.verifier.config.ContractVerifierConfigProperties configProperties, org.springframework.cloud.contract.verifier.builder.SingleTestGenerator generator, org.springframework.cloud.contract.verifier.FileSaver saver, org.springframework.cloud.contract.verifier.file.ContractFileScanner contractFileScanner) {}
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  int generate() { return (int)0;}
@groovy.transform.PackageScope() public  void generateTestClasses(java.lang.String basePackageName) { }
@groovy.transform.PackageScope() @groovy.transform.CompileDynamic() public  java.util.Set<java.util.Map.Entry<java.nio.file.Path, java.util.List<org.springframework.cloud.contract.verifier.file.ContractMetadata>>> processAll(org.springframework.util.MultiValueMap<java.nio.file.Path, org.springframework.cloud.contract.verifier.file.ContractMetadata> contracts, java.lang.String basePackageName) { return (java.util.Set<java.util.Map.Entry<java.nio.file.Path, java.util.List<org.springframework.cloud.contract.verifier.file.ContractMetadata>>>)null;}
protected static  java.lang.String buildPackage(java.lang.String packageNameForClass, java.lang.String includedDirectoryRelativePath) { return (java.lang.String)null;}
}
